#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MODULO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MODULO_HPP_INCLUDED

#include <boost/simd/operator/include/functions/modulo.hpp>

#endif
